% Example 10.5

clc
clear

%parameters
omega = 2*pi*60;
R = 10;
C = 0.01;
V0 = 120*sqrt(2);
tau = R*C;
Nmax = 800;

% diode = 1 when rectifier bridge is conducting
diode = 1;

%Here is the loop that does the work.
for n = 1:Nmax+1
   t(n) = (2.5*pi/omega)*(n-1)/Nmax;	%time
   vs(n) = V0*cos(omega*t(n));		%source voltage
   vrect(n) = abs(vs(n)); %full-wave rectified source voltage

%Calculations if the rectifier bridge is ON
if diode == 1

%If the bridge is ON, the resistor voltage is equal to the rectified
%source voltage.		
	vR(n) = vrect(n);		
%Check the total current out of rectifiers 
	if (omega*t(n)) <= pi/2.
		iB(n) = vR(n)/R - V0*C*omega*sin(omega*t(n));
	elseif (omega*t(n)) <= 3.*pi/2.
		iB(n) = vR(n)/R + V0*C*omega*sin(omega*t(n));
	else
		iB(n) = vR(n)/R - V0*C*omega*sin(omega*t(n));
	end

%If the current tries to go negative, the diodes will switch OFF
	if iB(n) < 0;
		diode = 0;
		toff = t(n);
		Voff = vrect(n);
	end
   else
%When the diodes are off, the resistor/capacitor voltage decays
%exponentially.
	vR(n) = Voff*exp(-(t(n)-toff)/tau);
	iB(n) = 0;
	if (vrect(n) - vR(n)) > 0;
		diode = 1;
	end 
   end
end

%Calculate the resistor current
iR = vR/R;

%Now plot vR as a solid line and vrect as a dashed line
plot(1000*t,vR)
xlabel('time [msec]')
ylabel('Voltage [V]')
axis ([0 22 0 180])
hold
plot(1000*t,vrect,'--')
hold

fprintf('\nHit any key to continue\n')
pause

%Now plot iR as a solid line and iL as a dashed line
plot(1000*t,iR)
xlabel('time [msec]')
ylabel('Source current [A]')
axis ([0 22 -50 250])
hold
plot(1000*t,iB,'--')
hold
