% Example 11.11

clc
clear

%Here are the 60-Hz motor parameters

V10 = 230/sqrt(3);
Nph = 3;
poles = 4;
fe0 = 60;

R1 = 0.095;
R2 = 0.2;
X10 = 0.680;
X20 = 0.672;
Xm0 = 18.7;

% Two frequency values

fe1 = 60;
fe2 = 40;

for m = 1:2,

   if m == 1
        fe = fe1;
   else
        fe = fe2;
   end

% Calculate the reactances and the voltage

   X1 = X10*(fe/fe0);
   X2 = X20*(fe/fe0);
   Xm = Xm0*(fe/fe0);
   V1 = V10*(fe/fe0);

%Calculate the synchronous speed

   omegas = 4*pi*fe/poles;
   ns = 120*fe/poles;

%Calculate stator Thevenin equivalent

   V1eq = abs(V1*j*Xm/(R1 + j*(X1+Xm)));
   Z1eq = j*Xm*(R1+j*X1)/(R1 + j*(X1+Xm));
   R1eq = real(Z1eq);
   X1eq = imag(Z1eq);

%Search over the slip until the Pload = Pmech

   slip = 0.;
   error = 1;
   
   while error >= 0;
      slip = slip + 0.00001;
      rpm = ns*(1-slip);
      omegam = omegas*(1-slip);
      Tmech = (1/omegas)*Nph*V1eq^2*(R2/slip);  
      Tmech = Tmech/((R1+R2/slip)^2 + (X1+X2)^2);
      Pmech = Tmech*omegam;
      Pload = 10.5e3*(rpm/1800)^3;
      
      error = Pload - Pmech;

   end  %End of while loop

   fprintf('\nFor fe = %g [Hz]:',fe)
   fprintf('\n   Terminal voltage = %g [V l-l]',V1*sqrt(3))
   fprintf('\n   rpm = %g',rpm)
   fprintf('\n   slip = %g [percent] ',100*slip)
   fprintf('\n   Pload = %g [kW]',Pload/1000)
   fprintf('\n\n')

end  
